@@ -56,36 +56,38 @@ import os
 
 import bioread
 
-from bidsphysio.base.bidsphysio import (physiosignal,
-                                        physiodata)
+from bidsphysio.base.bidsphysio import (PhysioSignal,
+                                        PhysioData)
 
 
-def acq2bids(physio_acq_files, trigger_label='trigger'):
+def acq2bids(physio_acq_files, trigger_labels=['trigger', 'digital input']):
     """Reads the physiological data from a series of AcqKnowledge
-    files and stores it in a physiodata member
+    files and stores it in a PhysioData member
 
     Parameters
     ----------
     physio_acq_files : list of str
         List of paths of the original physio files
-    trigger_label : str
-        Label of the channel that carries the scanner trigger.
+    trigger_labels : list of str
+        List with labels of the channel that carries the scanner trigger.
         Just one word from the channel name is enough
 
     Returns
     -------
-    physio : physiodata
-        physiodata with the contents of the file
+    physio : PhysioData
+        PhysioData with the contents of the file
     """
     # In case we are handled just a single file, make it a one-element list:
     if isinstance(physio_acq_files, str):
         physio_acq_files = [physio_acq_files]
+    if not isinstance(trigger_labels, list):
+        trigger_labels = [trigger_labels]
 
-    # Init physiodata object to hold physio signals:
-    physio = physiodata()
+    # Init PhysioData object to hold physio signals:
+    physio = PhysioData()
 
     # Read the files from the list, extract the relevant information and
-    #   add a new physiosignal to the list:
+    #   add a new PhysioSignal to the list:
     trigger_channel = ''
     for physio_acq in physio_acq_files:
         # Extract data from AcqKnowledge file:
@@ -103,7 +105,7 @@ def acq2bids(physio_acq_files, trigger_label='trigger'):
             elif 'resp' in item.name.lower():
                 physio_label = 'respiratory'
 
-            elif trigger_label.lower() in item.name.lower():
+            elif any([tl.lower() in item.name.lower() for tl in trigger_labels]):
                 physio_label = 'trigger'
                 trigger_channel = item.name
 
@@ -112,7 +114,7 @@ def acq2bids(physio_acq_files, trigger_label='trigger'):
 
             if physio_label:
                 physio.append_signal(
-                    physiosignal(
+                    PhysioSignal(
                         label=physio_label,
                         samples_per_second=item.samples_per_second,
                         sampling_times=item.time_index,
@@ -122,7 +124,7 @@ def acq2bids(physio_acq_files, trigger_label='trigger'):
                     )
                 )
 
-    # Get the "neuralstarttime" for the physiosignals by finding the first trigger.
+    # Get the "neuralstarttime" for the PhysioSignals by finding the first trigger.
     # We do this after we have read all signals to make sure we have read the trigger
     # (if present in the file. If not present, use the physiostart time. This is the
     # same as assuming the physiological recording started at the same time as the
@@ -131,8 +133,10 @@ def acq2bids(physio_acq_files, trigger_label='trigger'):
     # and not something else (e.g., stimulus trigger). So we print a warning.
     neuralstarttime = ''
     if trigger_channel:
-        print('Warning: Assuming {} channel corresponds to the scanner trigger'.format(trigger_channel))
-        neuralstarttime = physio.get_scanner_onset()
+        print('Warning: Assuming "{}" channel corresponds to the scanner trigger'.format(trigger_channel))
+        # The sampling_times are w.r.t. the start of the recording, so we need
+        # to also add the 'physiostarttime' (time when file was created):
+        neuralstarttime = physio.get_scanner_onset() + physiostarttime.timestamp()
     for p_signal in physio.signals:
         p_signal.neuralstarttime = neuralstarttime or p_signal.physiostarttime
         # we also fill with NaNs the places for which there is missing data:
